TOPSIS-Python
Submitted By: Vishal Gulati 101803152

pypi: https://pypi.org/project/TOPSIS-Vishal-101803152/

What is TOPSIS
Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) originated in the 1980s as a multi-criteria decision making method. TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution, and greatest distance from the negative-ideal solution. More details at wikipedia.


How to use this package:
TOPSIS-Vishal-101803152 can be run as in the following example:

In Command Prompt
>> pip install TOPSIS-Vishal-101803152==0.2
python

from topsis_gen.topsis_cal import topsis topsis("data.csv","1,1,1,2","+,+,-,+")


Sample dataset
The decision matrix (a) should be constructed with each row representing a Model alternative, and each column representing a criterion like Accuracy, R2, Root Mean Squared Error, Correlation, and many more.

Model	Correlation	R2	RMSE	Accuracy
M1	0.79	0.62	1.25	60.89
M2	0.66	0.44	2.89	63.07
M3	0.56	0.31	1.57	62.87
M4	0.82	0.67	2.68	70.19
M5	0.75	0.56	1.3	80.39
Weights (w) is not already normalised will be normalised later in the code.

Information of benefit positive(+) or negative(-) impact criteria should be provided in I.


Output
Model   Score    Rank
-----  --------  ----
  1    0.639133    2
  2    0.212592    5
  3    0.407846    4
  4    0.519153    3
  5    0.828267    1

The rankings are displayed in the form of a table using a package 'tabulate', with the 1st rank offering us the best decision, and last rank offering the worst decision making, according to TOPSIS method.
